.. _bokeh.plotting:

bokeh.plotting
==============

.. autofunction:: bokeh.plotting.figure.figure

.. autoclass:: bokeh.plotting.figure.Figure
    :members:
    :undoc-members:

.. autofunction:: bokeh.plotting.gmap.gmap

.. autoclass:: bokeh.plotting.gmap.GMapPlot
    :members:
    :undoc-members:
